#  tests for conda-wrappers-1.1.3-py38haa244fe_2 (this is a generated file);
print('===== testing package: conda-wrappers-1.1.3-py38haa244fe_2 =====');
print('running run_test.py');
#  --- run_test.py (begin) ---
import os
import sys

if sys.platform == 'win32':
    wrappers_dir = os.path.expandvars('$PREFIX/Scripts/wrappers/conda')
    ext = '.bat'
else:
    wrappers_dir = os.path.expandvars('$PREFIX/bin/wrappers/conda')
    ext = ''

assert os.path.isdir(wrappers_dir)
assert os.path.isfile(os.path.join(wrappers_dir, 'python' + ext))
#  --- run_test.py (end) ---

print('===== conda-wrappers-1.1.3-py38haa244fe_2 OK =====');



import os
import sys

if sys.platform == 'win32':
    wrappers_dir = os.path.expandvars('$PREFIX/Scripts/wrappers/conda')
    ext = '.bat'
else:
    wrappers_dir = os.path.expandvars('$PREFIX/bin/wrappers/conda')
    ext = ''

assert os.path.isdir(wrappers_dir)
assert os.path.isfile(os.path.join(wrappers_dir, 'python' + ext))
